from .agriculture import * # NOQA
from .arts_humanities import * # NOQA
from .upper_ontologies import * # NOQA
from .biology import * # NOQA
from .chemistry import * # NOQA
from .education import * # NOQA
from .ecology_environment import * # NOQA
from .events import * # NOQA
from .finance import * # NOQA
from .food_beverage import * # NOQA
from .general import * # NOQA
from .geography import * # NOQA
from .medicine import * # NOQA
from .industry import * # NOQA
from .law import * # NOQA
from .library_cultural_heritage import * # NOQA
from .material_science_engineering import * # NOQA
from .news_media import * # NOQA
from .scholarly_knowledge import * # NOQA
from .social_sciences import * # NOQA
from .units_measurements import * # NOQA
from .web import * # NOQA
